@@ -90,6 +90,9 @@ SERVICE_VERSIONS = {
     "bri": [
         "2019-03-28"
     ],
+    "bsca": [
+        "2021-08-11"
+    ],
     "btoe": [
         "2021-05-14",
         "2021-03-03"
@@ -121,6 +124,9 @@ SERVICE_VERSIONS = {
     "cds": [
         "2018-04-20"
     ],
+    "cfg": [
+        "2021-08-20"
+    ],
     "cfs": [
         "2019-07-19"
     ],
@@ -518,6 +524,7 @@ SERVICE_VERSIONS = {
         "2020-12-21"
     ],
     "thpc": [
+        "2022-04-01",
         "2021-11-09"
     ],
     "tia": [
